#!/usr/bin/env perl
# ESA (C) 2000-2020
#
# This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
#
#    SAS is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    SAS is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
#
#
#
package SAS;

$ImageDir="images";
$ImageType="gif";
$Email='xmmhelp@sciops.esa.int';

$PageLogoImage="xmmsaslogo";
$PageLogoImageAlt="XMM-Newton SAS Home Page";
$PageLogoTitle="XMM-Newton Science Analysis System";
$PageLogoSubTitle="";
$PageSasHomeRef="https://www.cosmos.esa.int/web/xmm-newton/sas";

sub joinTag
{
    local($ref,$title)=@_;
    if ($ref) {"<A HREF=$ref>$title</A>";}
    else      {"";}
}

# returns ($href,$title)
sub splitTag
{
    local($_)=@_;
    s/\n//og; #
    if (/HREF=([^\>]*)>(.*)<\/A>/) {($1,$2);} else {("","");}
}


# creates a BAR, used between actual BODY and NAVIGATION BUTTONS
sub navBar
{
    my($image)=@_;
    if ($image)
    {
	"<IMG BORDER=\"0\" SRC=\"$ImageDir/$image.$ImageType\">"
    }
    else
    {
	"<HR>"
    }
}


# navIcon(IMAGE,ALTIMAGE,HREF,TITLE)
#  returns *nothing* if HREF and ALTIMAGE do not exist
#  returns ALTIMAGE if HREF does not exist
#  otherwise returns clickable IMAGE, with alternative text:"TITLE".
sub navButton
{
    my($img,$altimg,$href,$title)=@_;
    my ($prefix,$suffix);


    if ($href) {
	if ($href !~ /^\".*\"$/) {$href="\"$href\"";}
	($prefix,$suffix)=("<A HREF=$href>","</A>");
    }
    else       {($img,$title)=($altimg,"[none]");}

    if ($img) {
	$prefix."<IMG BORDER=\"0\" SRC=\"$ImageDir/$img.$ImageType\" ALT=\"$title\">".$suffix;
    }
    else {
	"";
    }

}

# creates all the navigation Buttons from their original references.
# e.g. $refPrev is either empty or "<A HREF=foo.html>a title</A>"
sub navButtons
{
    my($refPrev,$refUp,$refNext,$refHome,$refMail,$refIndex)=@_;
    my $html;

    $html.=&navButton("prev", "dprev",&splitTag($refPrev))  ."\n";
    $html.=&navButton("up",   "",     &splitTag($refUp))    ."\n";
    $html.=&navButton("next", "dnext",&splitTag($refNext))  ."\n";
    $html.=&navButton("home", "",     &splitTag($refHome))  ."\n";
    $html.=&navButton("mail", "",     &splitTag($refMail))  ."\n";
    $html.=&navButton("index","",     &splitTag($refIndex)) ."\n";

    $html;
}


# creates TEXT in <BODY TEXT>. Note: not surrounded by '<' or '>', as 
# latex2html does not expect that!
sub bodyStart
{
    my($subtitle)=@_;
    my $h;

    if ($subtitle) {$PageLogoSubTitle=$subtitle;}

    $h.='TEXT="#000000" BGCOLOR="#FFFFFF" LINK="#0000EE"';
    $h.='VLINK="#551A8B" ALINK="#FF0000"';
    if ($subtitle !~ /^\s*$/) {
	my $image="<IMG SRC=\"$ImageDir/$PageLogoImage.$ImageType\"".
	    " ALT=\"$PageLogoImageAlt\" HEIGHT=60 WIDTH=60 ALIGN=\"LEFT\">";

	$h.=">".&joinTag($PageSasHomeRef,$image);
	$h.="<DIV ALIGN=RIGHT><B><FONT SIZE=+2>$PageLogoTitle</FONT><BR><BR><BR>";
	$h.=$PageLogoSubTitle."</B></DIV><BR CLEAR=ALL";
    }

    $h;
}

%SAS::IndexNames = (
		    'EventAttributes' => 'Index of event attributes',
		    'Parameters' => 'Index of task parameters',
		    'Errors' => 'Index of task errors',
		    'Warnings' => 'Index of task warnings',
		    'Environments' => 'Index of environment variables',
		    );

@SAS::Indexes = (
		 'Tasks',
		 'Parameters',
		 'Warnings',
		 'Errors',
		 'Environments',
		 'Attributes',
		 'Blocks',
		 'Columns',
		 'EventAttributes',
		 'Functions',
		 );
		 

1;
