% ESA (C) 2000-2018 
%
% This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
%
%    SAS is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    SAS is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
%% -------------------------------------------------
%% European Space Agency XMM Science Analysis System
%% -------------------------------------------------
%%
%% A document class based on article.cls
%%
%% 
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{sasbook}[1998/01/08 v1.0
    ESA XMM Science Analysis System document class
    $Revision: 1.6 $ $Date: 2009/02/05 15:40:14 $]

\RequirePackage{ifthen}
\RequirePackage{fancyhdr}
\RequirePackage{multirow}
\RequirePackage{epsfig}
\RequirePackage{float}

\newboolean{useronly}
\DeclareOption{useronly}{\setboolean{useronly}{true}}
\ProcessOptions

\LoadClass{book}

\mark{{}{}} 

\setlength{\textwidth}{16cm}
\setlength{\textheight}{23.5cm}
\setlength{\topmargin}{-1cm}
\setlength{\oddsidemargin}{0cm}
\setlength{\evensidemargin}{0cm}
\setlength{\leftmargini}{2cm}

\setlength{\parindent}{0in}             % No indent at start of paragraphs
\setlength{\parskip}{\baselineskip}     % Blank line between paragraph

\renewcommand\floatpagefraction{0.5}
\renewcommand\dblfloatpagefraction{0.5}
\def\fps@figure{!htbp}

\setcounter{secnumdepth}{5}    % numbering level of sections
\setcounter{tocdepth}{4}       % appearance level in table of contents

\pagestyle{fancy}

\addtolength{\headheight}{15mm}
%\addtolength{\headsep}{0mm}

\lhead{
  \psfig{file=xmmsaslogo.eps,height=1.5cm}
  {\bfseries\large XMM Science Analysis System} \vskip -1\baselineskip
  }

\rhead{
  \begin{tabular}{ll}
    Page:       & \thepage
  \end{tabular}
  }

\cfoot{}                        %empy footer, no page numbers at bottom


%% Here we plug in our own maketitle

\renewcommand\maketitle{
\chapter{\@title}
\@author\@date
}

\newenvironment{abstract}{%
      \if@twocolumn
        \section*{\abstractname}%
      \else
        \small
        \begin{center}%
          {\bfseries \abstractname\vspace{-.5em}\vspace{\z@}}%
        \end{center}%
        \quotation
      \fi}
      {\if@twocolumn\else\endquotation\fi}

\newcommand\abstractname{Abstract}

\renewcommand\chapter{\if@openright\cleardoublepage\else\clearpage\fi
                    \global\@topnum\z@
                    \@afterindentfalse
                    \secdef\@chapter\@schapter}
\def\@chapter[#1]#2{\ifnum \c@secnumdepth >\m@ne
                       \if@mainmatter
                         \refstepcounter{chapter}%
                         \typeout{\@chapapp\space\thechapter.}%
                         \addcontentsline{toc}{chapter}%
                                   {\protect\numberline{\thechapter}#1}%
                       \else
                         \addcontentsline{toc}{chapter}{#1}%
                       \fi
                    \else
                      \addcontentsline{toc}{chapter}{#1}%
                    \fi
                    \chaptermark{#1}%
                    \addtocontents{lof}{\protect\addvspace{10\p@}}%
                    \addtocontents{lot}{\protect\addvspace{10\p@}}%
                    \if@twocolumn
                      \@topnewpage[\@makechapterhead{#2}]%
                    \else
                      \@makechapterhead{#2}%
                      \@afterheading
                    \fi}

\def\@makechapterhead#1{%
  \vspace*{10\p@}%
  {\parindent \z@ \raggedright \normalfont
    \ifnum \c@secnumdepth >\m@ne
      \if@mainmatter
        \huge\bfseries \@chapapp\space \thechapter
        \par\nobreak
        \vskip 10\p@
      \fi
    \fi
    \interlinepenalty\@M
    \Huge \bfseries #1\par\nobreak
    \vskip 20\p@
  }}


\endinput



%% 
%% End of file `sasdoc.cls'.
