% ESA (C) 2000-2021
%
% This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
%
%    SAS is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    SAS is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
%% -------------------------------------------------
%% European Space Agency XMM Science Analysis System
%% -------------------------------------------------
%%
%% A document class based on article.cls
%%
%% 
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{sasdoc}[11/11/2021 XMM-Newton Science Analysis System (SAS) document class]

\RequirePackage{ifthen}
\RequirePackage{fancyhdr}
\RequirePackage{multirow}
\RequirePackage{epsfig}
\RequirePackage{float}
\RequirePackage{graphicx}

%%% Obsolete
%%\newboolean{useronly}
%%\DeclareOption{useronly}{\setboolean{useronly}{true}}
\newcommand{\sasfooter}{\cfoot{standard}}
\DeclareOption{version}{\renewcommand{\sasfooter}{\lfoot{\texttt{\InputIfFileExists{sasdoc_version.tex}}}}}
\ProcessOptions

\LoadClass{article}

\mark{{}{}} 

% A4 paper
\setlength{\paperwidth}{21cm}
\setlength{\paperheight}{29.7cm}
% Space left for text
\setlength{\textwidth}{16cm}
\setlength{\textheight}{23cm}
% SAS Logo and name will be embedded in the part not avilable for text
\setlength{\topmargin}{-1cm}
%
\setlength{\oddsidemargin}{0cm}
\setlength{\evensidemargin}{0cm}
%
\setlength{\leftmargin}{1cm}
%
\setlength{\footskip}{1.5cm}

\setlength{\parindent}{0in}             % No indent at start of paragraphs
\setlength{\parskip}{\baselineskip}     % Blank line between paragraph

\renewcommand\floatpagefraction{0.5}
\renewcommand\dblfloatpagefraction{0.5}
\def\fps@figure{!htbp}

\setcounter{secnumdepth}{5}    % numbering level of sections
\setcounter{tocdepth}{8}       % appearance level in table of
                               % contents. Some packages do this deep.

\pagestyle{fancy}
\fancyhf{}

% Header 
% Height=1.5 cm with sufficient space to hold the SAS logo (see below)
\addtolength{\headheight}{15mm}
%\addtolength{\headsep}{0mm}



\lhead{
  \psfig{file=xmmsaslogo.eps,height=1.5cm}
  %\includegraphics[height=1.5cm]{xmmsaslogo.eps}
  {\bfseries\large XMM-Newton Science Analysis System} \vskip -1\baselineskip
  }

% Add a table to hold the page number
\rhead{
  \begin{tabular}{ll}
    \CurrentOption Page:       & \thepage
  \end{tabular}
  }
\sasfooter
%%%\cfoot{}                        %empy footer, no page numbers at bottom

%% Here we plug in our own maketitle

\if@titlepage
  \renewcommand\maketitle{\begin{titlepage}%
  \let\footnotesize\small
  \let\footnoterule\relax
  \let \footnote \thanks
  \null\vfil
  \vskip 60\p@
  \begin{center}%
    {\LARGE \@title \par}%
    \vskip 3em%
    {\large
     \lineskip .75em%
      \begin{tabular}[t]{c}%
        \@author
      \end{tabular}\par}%
      \vskip 1.5em%
    {\large \@date \par}%       % Set date in \large size.
  \end{center}\par
  \@thanks
  \vfil\null
  \end{titlepage}%
  \setcounter{footnote}{0}%
  \global\let\thanks\relax
  \global\let\maketitle\relax
  \global\let\@thanks\@empty
  \global\let\@author\@empty
  \global\let\@date\@empty
  \global\let\@title\@empty
  \global\let\title\relax
  \global\let\author\relax
  \global\let\date\relax
  \global\let\and\relax
}
\else
  \renewcommand\maketitle{\par
  \begingroup
    \renewcommand\thefootnote{\@fnsymbol\c@footnote}%
    \def\@makefnmark{\rlap{\@textsuperscript{\normalfont\@thefnmark}}}%
    \long\def\@makefntext##1{\parindent 1em\noindent
            \hb@xt@1.8em{%
                \hss\@textsuperscript{\normalfont\@thefnmark}}##1}%
    \if@twocolumn
      \ifnum \col@number=\@ne
        \@maketitle
      \else
        \twocolumn[\@maketitle]%
      \fi
    \else
      \newpage
      \global\@topnum\z@   % Prevents figures from going at top of page.
      \@maketitle
    \fi
    \thispagestyle{fancy}\@thanks
  \endgroup
  \setcounter{footnote}{0}%
  \global\let\thanks\relax
  \global\let\maketitle\relax
  \global\let\@maketitle\relax
  \global\let\@thanks\@empty
  \global\let\@author\@empty
  \global\let\@date\@empty
  \global\let\@title\@empty
  \global\let\title\relax
  \global\let\author\relax
  \global\let\date\relax
  \global\let\and\relax
}
\def\@maketitle{%
  \newpage
  \null
  \vskip 2em%
  \begin{center}%
  \let \footnote \thanks
    {\LARGE \@title \par}%
    \vskip 1.5em%
    {\large
      \lineskip .5em%
      \begin{tabular}[t]{c}%
        \@author
      \end{tabular}\par}%
    \vskip 1em%
    {\large \@date}%
  \end{center}%
  \par
  \vskip 1.5em}
\fi


\endinput



%% 
%% End of file `sasdoc.cls'.
